Available models
================

Models adapted from funcFit and the modelSuite.

See :ref:`modelSuite` for further information on the models.

Basic models
------------

.. note:: The names of the basic models are available also without the '1d' ending.


- GaussFit1d
- MultiGaussFit1d
- CauchyLorentz1d
- Voigt1d
- MultiVoigt1d
- SinusFit1d
- ExpDecayFit1d
- PolyFit1d
- ConstantFit1d

More advanced models
--------------------

- PalLC
- PalLCKep
- MandelAgolLC
- MandelAgolNLLC
- LimBrightTrans
- RmcL
- RmcLell
- SinRadVel
- KeplerEllipseModel
- KeplerRVModel
- LLGauss
- VoigtAstroP
- LyaTransmission
- RotBroadProfile
  
  